<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Company extends Home_Controller {

    public function __construct()
    {
        parent::__construct();
        header('Access-Control-Allow-Origin: *');
    }

    //company landing page function
    public function home($slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Company Home';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        if(empty($data['company'])){
            redirect(base_url('404_override'));
        }
        $data['teams'] = $this->common_model->get_home_team($data['company']->uid,6);
        $data['blogs']=$this->common_model->get_home_blogs($data['company']->uid,4);
        $data['services']=$this->common_model->get_home_services($data['company']->uid,6);
        $data['counters']=$this->common_model->get_home_counters($data['company']->uid,2);
        $data['testimonials']=$this->common_model->get_home_testimonials($data['company']->uid,6);
        $data['sliders']=$this->common_model->get_home_sliders($data['company']->uid,6);
        $data['products'] = $this->common_model->get_home_products($data['company']->uid, 8);
        $data['portfolios']=$this->common_model->get_home_portfolios($data['company']->uid,6);

        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/home'.$data['company']->home_style, $data, TRUE);
        $this->load->view('index', $data);
    }


    //company teams
    public function teams($slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Teams';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        $data['teams'] = $this->common_model->get_data($data['company']->uid, 'teams');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/teams', $data, TRUE);
        $this->load->view('index', $data);
    }

    //all events
    public function events($slug)
    {   
        $data = array();
        $config['base_url'] = base_url('company/events/'.$slug);
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $total_row = $this->common_model->get_events($data['company']->uid, $total=1, 0, 0);
        $config['total_rows'] = $total_row;
        $config['per_page'] =$data['company']->pagination_limit;
        $this->pagination->initialize($config);
        $page = $this->security->xss_clean($this->input->get('page'));
        if (empty($page)) {
            $page = 0;
        }
        if ($page != 0) {
            $page = $page - 1;
        }
        $data['page'] = 'Company';
        $data['page_title'] = 'Events';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['events']=$this->common_model->get_events($data['company']->uid, $total=0, $config['per_page'], $page * $config['per_page']);
        $data['categories'] = $this->admin_model->get_categories($data['company']->uid, 'event',1 );
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/events', $data, TRUE);
        $this->load->view('index', $data);
    }

    //event details
    public function event_details($event_slug,$slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Event_details';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['single_event'] = $this->common_model->get_by_slug($event_slug, 'events');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/event_details', $data, TRUE);
        $this->load->view('index', $data);
    }


    //event submit page
    public function event_submit($event_id,$slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Event Booking';
        $data['slug'] = $slug;
        $data['event_id'] = $event_id;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['countries'] = $this->common_model->select('country');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/event_booking', $data, TRUE);
        $this->load->view('index', $data);
    }

    //book event
    public function event_booking($event_id,$slug)
    {  

        $data = array();
        $company = $this->common_model->get_by_slug($slug, 'business');
        $type = $this->input->post('type');

        if($type == 'register'){
            $mail = $this->input->post('email',true);
            $check_email = $this->auth_model->check_duplicate_email($mail);
            if ($check_email){
                $msg = trans('email-exist');
                echo json_encode(array('st'=>0, 'msg' => $msg));
                exit();
            }

            $data = array(
                'user_id' => user()->id,
                'business_id' =>$company->uid,
                'name' =>$this->input->post('name', true), 
                'email' =>$this->input->post('email', true), 
                'password' =>hash_password($this->input->post('password', true)), 
                'zip' =>$this->input->post('zip', true), 
                'phone' =>$this->input->post('phone', true), 
                'country' =>$this->input->post('country', true), 
                'city' =>$this->input->post('city', true), 
                'state' =>$this->input->post('state', true), 
                'address' =>$this->input->post('address', true),
                'created_at' => my_date_now()
            );
            $data = $this->security->xss_clean($data);
            $customer_id = $this->admin_model->insert($data, 'customers');
            $customer = $this->common_model->get_by_id($customer_id,'customers');
        }else{
            $user_name = $this->input->post('user_name',true);
            $customer = $this->common_model->check_customer_email($user_name);
            if (!empty($customer)) {
                $customer_id = $customer->id;
            } else {
                $msg = trans('incorrect-username-or-password');
                echo json_encode(array('st'=>0, 'msg' => $msg)); exit();
            }

            if(!password_verify($this->input->post('password',true), $customer->password)){
                $msg = trans('incorrect-username-or-password');
                echo json_encode(array('st'=>0, 'msg' => $msg)); exit();
            }
        }

        $data = array(
            'id' => $customer->id,
            'name' => $customer->name,
            'slug' => $customer->slug,
            'thumb' => $customer->thumb,
            'email' =>$customer->email,
            'role' =>$customer->role,
            'logged_in' => TRUE
        );
        $data = $this->security->xss_clean($data);
        $this->session->set_userdata($data);

        $code = random_string('numeric', 5);
        $get_price=$this->common_model->get_price_event($event_id);
        $odata = array( 
            'business_id' =>$company->uid,
            'customer_id' => $customer_id,
            'event_id' => $event_id,
            'booking_id' => $code,
            'quantity' =>$this->input->post('quantity', true),
            'total_price' =>$get_price->price * $this->input->post('quantity',true),
            'description' =>$this->input->post('description', true),
            'payment_type' =>$this->input->post('payment_type', true),
            'payment_status' => 'pending',
            'booking_date' => my_date_now()
        );
        $odata = $this->security->xss_clean($odata);
        $booking_id = $this->admin_model->insert($odata, 'event_booking');

        echo json_encode(array('st' => 1, 'url'=> base_url('customer/payment/'.md5($booking_id).'/event')));
    } 


    //page details
    public function page_details($slug,$page_slug)
    {  

        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Page details';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['company_page'] = $this->common_model->get_by_slug($page_slug, 'pages');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/page_details', $data, TRUE);
        $this->load->view('index', $data);
    }

    //contact
    public function contact($slug)
    {  
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Contact';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/contact', $data, TRUE);
        $this->load->view('index', $data);
    }

    //quote
    public function quote($slug)
    {  
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Quote';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/quote', $data, TRUE);
        $this->load->view('index', $data);
    }

    //send quote
    public function add_quote()
    {
        check_status();
        
        if($_POST)
        {   
            $id = $this->input->post('id', true);
            $data=array(
                'lang_id' => 1,
                'business_id' => $this->input->post('business_id', true),
                'user_id' => $this->input->post('user_id', true),
                'name' => $this->input->post('name', true),
                'subject' => $this->input->post('subject', true),
                'email' => $this->input->post('email', true),
                'details' => $this->input->post('details', true),
                'status' =>1,
            );
            $data = $this->security->xss_clean($data);


            if (!empty($id)) {
                $this->admin_model->edit_option($data, $id, 'quotes');
                $this->session->set_flashdata('msg', trans('updated-successfully')); 
            } else {
                $id = $this->admin_model->insert($data, 'quotes');
                $this->session->set_flashdata('msg', trans('inserted-successfully')); 
            }
            if(!empty($_FILES['file']['name'])){
               $new_name = "file_".strtolower(uniqid().'.'.pathinfo($_FILES['file']['name'], PATHINFO_EXTENSION));

                $config['upload_path']          = './uploads/files'; //file save path
                $config['allowed_types']        = 'pdf';
                $config['max_size']             = 10000;
                $config['file_name'] = $new_name;


                $this->load->library('upload', $config);
                if ( ! $this->upload->do_upload('file'))
                {
                    $error =  $this->upload->display_errors();
                    $this->session->set_flashdata('msg', $error);
                    
                }else{

                    $data = array(
                        'file' => 'uploads/files/' . $new_name,
                    );
                    $data = $this->security->xss_clean($data);
                    $this->admin_model->edit_option($data,$id,'quotes');
                } 
            }
            
            
            redirect($_SERVER['HTTP_REFERER']);

        }      
    }

    //send contact message
    public function contact_submit()
    {   
        check_status();
        
        if($_POST)
        { 
            $data=array(
                'business_id' => $this->input->post('business_id', true) ,
                'name' => $this->input->post('name', true),
                'email' => $this->input->post('email', true),
                'message' => $this->input->post('message', true),
                'created_at' =>my_date_now(),
            );
            $data = $this->security->xss_clean($data);
            $id = $this->admin_model->insert($data, 'contacts');
            $this->session->set_flashdata('msg', trans('sent-message-successfully'));
            redirect($_SERVER['HTTP_REFERER']);

        }      
        
    }

    //show all services
    public function services($slug)
    {   
        $data = array();
        $config['base_url'] = base_url('company/services/'.$slug);
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $total_row = $this->common_model->get_services($data['company']->uid, $total=1, 0, 0);
        $config['total_rows'] = $total_row;
        $config['per_page'] = $data['company']->pagination_limit;
        $this->pagination->initialize($config);
        $page = $this->security->xss_clean($this->input->get('page'));
        if (empty($page)) {
            $page = 0;
        }
        if ($page != 0) {
            $page = $page - 1;
        }
        $data['page'] = 'Company';
        $data['page_title'] = 'Services';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['services']=$this->common_model->get_services($data['company']->uid, $total=0, $config['per_page'], $page * $config['per_page']);
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/services', $data, TRUE);
        $this->load->view('index', $data);
    }


    //book service view page
    public function book_service($slug)
    {   
        $data = array();
        if($_POST){
            $sdata = array(
                'service_id' => $this->input->post('service_id', true),
                'date' => $this->input->post('date', true),
                'time' => $this->input->post('time', true),
            );
            $this->session->set_userdata($sdata);
            
        }
        $data['page'] = 'Company';
        $data['page_title'] = 'Service Booking';
        $data['slug'] = $slug;
        $data['type'] = 'service';
        $data['menu'] = FALSE;
        $data['service_id'] = $this->input->post('service_id',true);
        $data['service'] = $this->common_model->get_by_id($this->session->userdata('service_id'), 'services');
        //echo "<pre>"; print_r($data['service_id']); exit();
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['countries'] = $this->common_model->select('country');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
            

        $data['main_content'] = $this->load->view('templates/style_1/service_booking', $data, TRUE);
        $this->load->view('index', $data);
    }

    //service booking
    public function service_booking($service_id,$slug)
    {  
        $data = array();
        $company = $this->common_model->get_by_slug($slug, 'business');
        $type = $this->input->post('type',true);

        if($type == 'register'){
            $mail = $this->input->post('email',true);
            $check_email = $this->auth_model->check_duplicate_email($mail);
            if ($check_email){
                $msg = trans('email-exist');
                echo json_encode(array('st'=>0, 'msg' => $msg));
                exit();
            }

            $data = array(
                'user_id' => user()->id,
                'business_id' =>$company->uid,
                'name' =>$this->input->post('name', true), 
                'email' =>$this->input->post('email', true), 
                'password' =>hash_password($this->input->post('password', true)), 
                'zip' =>$this->input->post('zip', true), 
                'phone' =>$this->input->post('phone', true), 
                'country' =>$this->input->post('country', true), 
                'city' =>$this->input->post('city', true), 
                'state' =>$this->input->post('state', true), 
                'address' =>$this->input->post('address', true),
                'created_at' => my_date_now()
            );
            $data = $this->security->xss_clean($data);
            $customer_id = $this->admin_model->insert($data, 'customers');
            $customer = $this->common_model->get_by_id($customer_id,'customers');
        }else{
            $user_name = $this->input->post('user_name', true);
            $customer = $this->common_model->check_customer_email($user_name);
            if (!empty($customer)) {
                $customer_id = $customer->id;
            } else {
                $msg = trans('incorrect-username-or-password');
                echo json_encode(array('st'=>0, 'msg' => $msg)); exit();
            }

            if(!password_verify($this->input->post('password', true), $customer->password)){
                $msg = trans('incorrect-username-or-password');
                echo json_encode(array('st'=>0, 'msg' => $msg)); exit();
            }
        }

        $data = array(
            'id' => $customer->id,
            'name' => $customer->name,
            'slug' => $customer->slug,
            'thumb' => $customer->thumb,
            'email' =>$customer->email,
            'role' =>$customer->role,
            'logged_in' => TRUE
        );
        $data = $this->security->xss_clean($data);
        $this->session->set_userdata($data);

        $code = random_string('numeric', 5);
        $odata = array( 
            'business_id' =>$company->uid,
            'customer_id' => $customer_id,
            'service_id' => $service_id,
            'number' => $code,
            'price' => get_by_id($service_id,'services')->price,
            'duration' => get_by_id($service_id,'services')->duration,
            'date' =>$this->input->post('date', true),
            'time' =>$this->input->post('time', true),
            'payment_status' => 'pending',
            'status' => 'pending',
            'created_at' => my_date_now()
        );
        $odata = $this->security->xss_clean($odata);
        $booking_id = $this->admin_model->insert($odata, 'appointments');

        echo json_encode(array('st' => 1, 'url'=> base_url('customer/payment/'.md5($booking_id).'/service')));
    } 

    //service details
    public function service_details($service_slug, $slug)
    {   
        $data = array();
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['page'] = 'Company';
        $data['page_title'] = 'Service';
        $my_days = $this->admin_model->get_my_days($data['company']->uid);
        foreach ($my_days as $day) {
            if ($day['day'] != 0) {
                $myday[] = $day['day'];
            }
        }

        $days = "1,2,3,4,5,6,7";         
        $days = explode(',', $days);
        $assign_days = $myday;

        $match = array();
        $nomatch = array();

        foreach($days as $v){     
            if(in_array($v, $assign_days))
                $match[]=$v;
            else
                $nomatch[]=$v;
        }
        $data['not_available'] = $nomatch;
        $data['my_days'] = $my_days;
       
        $data['page'] = 'Company';
        $data['page_title'] = 'Booking';



        $data['type'] = 'service';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['service'] = $this->common_model->get_by_slug($service_slug, 'services');
        $data['categories'] = $this->admin_model->get_categories($data['company']->uid, 'service',1 );
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/service_details', $data, TRUE);
        $this->load->view('index', $data);
    }

    //show all blogs
    public function blogs($slug='')
    {   
        $data = array();
        $config['base_url'] = base_url('company/blogs/'.$slug);
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $total_row = $this->common_model->get_blogs($data['company']->uid, 'blogs', $total=1, 0, 0);
        $config['total_rows'] = $total_row;
        $config['per_page'] =$data['company']->pagination_limit;
        $this->pagination->initialize($config);
        $page = $this->security->xss_clean($this->input->get('page'));
        if (empty($page)) {
            $page = 0;
        }
        if ($page != 0) {
            $page = $page - 1;
        }

        $data['page'] = 'Company';
        $data['page_title'] = 'Blogs';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        $data['blogs']=$this->common_model->get_blogs($data['company']->uid, 'blogs' , $total=0, $config['per_page'], $page * $config['per_page']);
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/blogs', $data, TRUE);
        $this->load->view('index', $data);
    }

    // blog details page
    public function blog_details($blog_slug,$slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Blog';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['post'] = $this->common_model->get_by_slug($blog_slug, 'blogs');
        $data['categories'] = $this->admin_model->get_categories($data['company']->uid, 'blog', '1');
        $data['comments']= $this->common_model->get_comments($data['post']->id);
        $data['related_blogs'] = $this->common_model->get_related_blogs($data['post']->id,$data['company']->uid, 3);
        $data['popular_blogs'] = $this->common_model->get_popular_blogs($data['company']->uid,3);
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $views = array(
            'total_views' =>$data['post']->total_views+1  
        );
        $this->common_model->edit_option($views,$data['post']->id,'blogs');
        $data['main_content'] = $this->load->view('templates/style_1/blog_details', $data, TRUE);
        $this->load->view('index', $data);
    }

    //add blog comment
    public function comment_add($slug)
    {   
        check_status();
        if($_POST)
        { 
            $data=array(
                'user_id' => 0,
                'post_id'=>$this->input->post('post_id', true),
                'name' => $this->input->post('name', true),
                'email' => $this->input->post('email', true),
                'message' => $this->input->post('message', true),
                'created_at' =>my_date_now(),
            );
            $data = $this->security->xss_clean($data);
            $id = $this->admin_model->insert($data, 'comments');
            $this->session->set_flashdata('msg', trans('commented-successfully'));
            redirect($_SERVER['HTTP_REFERER']);
        }  
    }

    //show all products
    public function product($slug)
    {   
        $data = array();
        $config['base_url'] = base_url('company/product/'.$slug);
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $total_row = $this->common_model->get_products($data['company']->uid, $total=1, 0, 0);
        $config['total_rows'] = $total_row;
        $config['per_page'] =$data['company']->pagination_limit;
        $this->pagination->initialize($config);
        $page = $this->security->xss_clean($this->input->get('page'));
        if (empty($page)) {
            $page = 0;
        }
        if ($page != 0) {
            $page = $page - 1;
        }

        $data['page'] = 'Company';
        $data['page_title'] = 'Products';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        $data['products']=$this->common_model->get_products($data['company']->uid, $total=0, $config['per_page'], $page * $config['per_page']);
        $data['categories'] = $this->admin_model->get_categories($data['company']->uid, 'product',1 );
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/products', $data, TRUE);
        $this->load->view('index', $data);
    }

    //product details
    public function product_details($product_slug,$slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Product';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['product'] = $this->common_model->get_by_slug($product_slug, 'products');
        $data['categories'] = $this->admin_model->get_categories($data['company']->uid, 'product',1 );
        $data['subcategories'] = $this->admin_model->get_subcategories($data['company']->uid, 'product', 'all');
        $data['product_images'] = $this->common_model->get_product_img($data['product']->id,6);
        $data['related_products'] = $this->common_model->get_related_products($data['product']->id,$data['company']->uid, 4);
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/product_details', $data, TRUE);
        $this->load->view('index', $data);
    }

    //product cat page
    public function cart($slug)
    {  
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Shopping Cart';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/cart', $data, TRUE);
        $this->load->view('index', $data);
    }


    //add to cart function
    public function add_to_cart($product_id, $slug) {
      
        $product = $this->common_model->get_by_id($product_id, 'products');
        $product_img = $this->common_model->get_single_product_img($product_id, 1);

        if (empty($product_img)) {
            $thumb = 'assets/front/img/no-image.png';
        }else{
            $thumb = $product_img->thumb;
        }
        
        if ($product->quantity >= $quantity) {
            if (!empty($product)) {
               
                $price = $product->price;
                $data = array();
                $data['slug'] = $slug;
                $data['company'] = $this->common_model->get_by_slug($slug, 'business');
                $cdata = array(
                    'id' => $product_id,
                    'qty' => 1,
                    'price' => $price,
                    'delivery_charge' => 0,
                    'thumb' => $thumb,
                    'name' => str_replace("'", "", $product->title)
                );
                $this->cart->insert($cdata);
                $this->session->set_flashdata('msg', 'This Product has been added to your cart');
            }
        } else {
            $quantity = $product->quantity;
            $this->session->set_flashdata('msg', 'Available Stock is ' .$quantity. '. Please order in available stock.');
        }

        redirect($_SERVER['HTTP_REFERER']);
    }


    //add to cart single product
    public function add_to_cart_single($slug) 
    {
        $product_id = $this->input->post('product_id', true);
        $product_sku_id = $this->input->post('product_sku_id', true);
        $quantity = $this->input->post('quantity', true);
        $product = $this->common_model->get_by_id($product_id, 'products');
    
        $product_img = $this->common_model->get_single_product_img($product_id, 1);
        if (empty($product_img)) {
            $thumb = 'assets/front/img/no-image.png';
        }else{
            $thumb = $product_img->thumb;
        }
        
        if ($product->quantity >= $quantity) {
            if (!empty($product)) {
               
                $price = $product->price;

                $discount = 0;
                if ($discount != 0) {
                    if ($pro['discount'] == 0) {
                        $price = $pro['price'];
                    } else {
                        $price = ($pro['price'] - ($pro['price'] * ($pro['discount'] / 100)));
                    }
                }

                $data = array();
                $data['slug'] = $slug;
                $data['company'] = $this->common_model->get_by_slug($slug, 'business');
                $cdata = array(
                    'id' => $product_id,
                    'qty' => $this->input->post('quantity'),
                    'price' => $price,
                    'delivery_charge' => 0,
                    'thumb' => $thumb,
                    'name' => str_replace("'", "", $product->title)
                );
                $this->cart->insert($cdata);
                $load_data = $this->load->view('include/header_cart', $data, TRUE);
                echo json_encode(array('st' => 1, 'cartData' => $load_data, 'totalQty' => $this->cart->total_items()));
                
            }
        } else {
            $quantity = $product->quantity;
            echo json_encode(array('st' => 0,'stock'=>$quantity));
        }
    }

    //check product quantity
    public function quantity_check($id) {
        $product = $this->common_model->get_by_id($id, 'products');
        $quantity = $product->quantity;

        $cart = $this->cart->contents();
        $cart_qty = 0;
        foreach ($cart as $crt) {
            if ($crt['id'] == $id) {
                $cart_qty = $crt['qty'];
            }
        }

        if ($cart_qty >= $quantity) {
            return false;
        } else {
            return true;
        }
    }


    function remove_cart_item($rowid) {   
        $data = array(
            'rowid'   => $rowid,
            'qty'     => 0
        );

        $this->cart->update($data);
        echo json_encode(array('st' => 1));
    }

    function update_cart() {
        $items = $this->input->post('items', true);
        $qty = $this->input->post('qty', true);
        
        for ($i=0; $i < count($items); $i++) { 
            $data = array(
                'rowid' => $items[$i],
                'qty' => $qty[$i]
            );
            $this->cart->update($data);
        }
        $this->session->set_flashdata('msg', trans('updated-successfully'));
        redirect($_SERVER['HTTP_REFERER']);
    }

    function distroy_cart(){
        $this->cart->destroy();
        echo json_encode(array('st' => 1));
    }

    //checkout function
    public function check_out($slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Check Out';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['countries'] = $this->common_model->select('country');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/check_out', $data, TRUE);
        $this->load->view('index', $data);
    }


    //submit order
    public function order_submit($slug)
    {  
        $data = array();
        $company = $this->common_model->get_by_slug($slug, 'business');
        $type = $this->input->post('type',true);

        if($type == 'register'){
            $mail = $this->input->post('email',true);
            $check_email = $this->auth_model->check_duplicate_email($mail);
            if ($check_email){
                $msg = trans('email-exist');
                echo json_encode(array('st'=>0, 'msg' => $msg));
                exit();
            }

            $data = array(
                'user_id' => user()->id,
                'business_id' =>$company->uid,
                'name' =>$this->input->post('name',true), 
                'email' =>$this->input->post('email',true), 
                'password' =>hash_password($this->input->post('password',true)), 
                'zip' =>$this->input->post('zip',true), 
                'phone' =>$this->input->post('phone',true), 
                'country' =>$this->input->post('country',true), 
                'city' =>$this->input->post('city',true), 
                'state' =>$this->input->post('state',true), 
                'address' =>$this->input->post('address',true)
            );
            $data = $this->security->xss_clean($data);
            $customer_id = $this->admin_model->insert($data, 'customers');
            $customer = $this->common_model->get_by_id($customer_id,'customers');
        }else{
            $user_name = $this->input->post('user_name',true);
            $customer = $this->common_model->check_customer_email($user_name);
            if (!empty($customer)) {
                $customer_id = $customer->id;
            } else {
                $msg = trans('incorrect-username-or-password');
                echo json_encode(array('st'=>0, 'msg' => $msg)); exit();
            }

            if(!password_verify($this->input->post('password',true), $customer->password)){
                $msg = trans('incorrect-username-or-password');
                echo json_encode(array('st'=>0, 'msg' => $msg)); exit();
            }
        }

        $data = array(
            'id' => $customer->id,
            'name' => $customer->name,
            'slug' => $customer->slug,
            'thumb' => $customer->thumb,
            'email' =>$customer->email,
            'role' =>$customer->role,
            'logged_in' => TRUE
        );
        $data = $this->security->xss_clean($data);
        $this->session->set_userdata($data);
                
        $code = random_string('numeric', 5);
        $odata = array( 
            'business_id' =>$company->uid,
            'customer_id' => $customer_id,
            'order_id' => $code,
            'total_items' => $this->cart->total_items(),
            'total_price' => $this->cart->total(),
            'payment_type' => $this->input->post('payment_type', true, true),
            'payment_status' => 'pending',
            'order_status' => 'processing',
            'created_at' => my_date_now()
        );
        $odata = $this->security->xss_clean($odata);
        $order_id = $this->admin_model->insert($odata, 'product_orders');


        foreach ($this->cart->contents() as $item):
            $oldata = array( 
                'order_id' => $order_id, 
                'product_id' => $item['id'], 
                'qty' => $item['qty'],
                'price' => $item['price']
            );
            $this->admin_model->insert($oldata, 'product_order_lists');
        endforeach; 

        echo json_encode(array('st' => 1, 'url'=> base_url('customer/payment/'.md5($order_id).'/product')));
        
    }

    
    //portfolios
    public function portfolios($slug)
    {   
        $data = array();
        $config['base_url'] = base_url('company/portfolios/'.$slug);
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $total_row = $this->common_model->get_portfolios($data['company']->uid, $total=1, 0, 0);
        $config['total_rows'] = $total_row;
        $config['per_page'] =$data['company']->pagination_limit;
        $this->pagination->initialize($config);
        $page = $this->security->xss_clean($this->input->get('page'));
        if (empty($page)) {
            $page = 0;
        }
        if ($page != 0) {
            $page = $page - 1;
        }
        $data['page'] = 'Company';
        $data['page_title'] = 'Portfolios';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['categories'] = $this->admin_model->get_categories($data['company']->uid, 'portfolio',1 );
        $data['portfolios'] = $this->common_model->get_portfolios($data['company']->uid,$total=0, $config['per_page'], $page * $config['per_page']
            );
        //echo "<pre>"; print_r($data['portfolios']); exit();
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/portfolios', $data, TRUE);
        $this->load->view('index', $data);
    }

    //portfolio details
    public function portfolio_details($portfolio_slug,$slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Portfolio';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        $data['single_portfolio'] = $this->common_model->get_by_slug($portfolio_slug, 'portfolios');
        $data['related_portfolios'] = $this->common_model->get_related_portfolios($data['single_portfolio']->id,$data['company']->uid, 6 );
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/portfolio_details', $data, TRUE);
        $this->load->view('index', $data);
    }

    //careers
    public function careers($slug)
    {   
        $data = array();
        $config['base_url'] = base_url('company/careers/'.$slug);
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $total_row = $this->common_model->get_careers($data['company']->uid, $total=1, 0, 0);
        $config['total_rows'] = $total_row;
        $config['per_page'] =$data['company']->pagination_limit;
        $this->pagination->initialize($config);
        $page = $this->security->xss_clean($this->input->get('page'));
        if (empty($page)) {
            $page = 0;
        }
        if ($page != 0) {
            $page = $page - 1;
        }
        $data['page'] = 'Company';
        $data['page_title'] = 'Careers';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['careers'] = $this->common_model->get_careers($data['company']->uid,$total=0, $config['per_page'], $page * $config['per_page']
            );
        $data['categories'] = $this->admin_model->get_categories($data['company']->uid, 'job',1 );
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/careers', $data, TRUE);
        $this->load->view('index', $data);
    }

    //career details
    public function career_details($career_slug,$slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Career_details';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['single_career'] = $this->common_model->get_by_slug($career_slug, 'jobs');
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/career_details', $data, TRUE);
        $this->load->view('index', $data);
    }

    //apply for job
    public function career_apply($slug)
    {   
        check_status();
        
        $company= $this->common_model->get_by_slug($slug, 'business');
        if($_POST)
        { 
            $data=array(
                'business_id' =>$company->uid,
                'user_id' =>$company->user_id,
                'job_id'=>$this->input->post('id', true),
                'applicant_name' => $this->input->post('aplicant_name', true),
                'applicant_email' => $this->input->post('email', true),
                'applicant_message' => $this->input->post('applicant_message', true),
                'expected_salary' => $this->input->post('expected_salery', true),
                'apply_date' =>my_date_now(),
                'status' => 0,
            );
            $data = $this->security->xss_clean($data);
            $id = $this->admin_model->insert($data, 'job_applicants');
            $this->session->set_flashdata('msg', trans('applied-successfully'));

            $new_name = "file_".strtolower(uniqid().'.'.pathinfo($_FILES['file']['name'], PATHINFO_EXTENSION));

            $config['upload_path']          = './uploads/files';
            $config['allowed_types']        = 'pdf';
            $config['max_size']             = 10000;
            $config['file_name'] = $new_name;


            $this->load->library('upload', $config);
            if ( ! $this->upload->do_upload('file'))
            {
                $error = array('error' => $this->upload->display_errors());
                $this->session->set_flashdata('msg', $error);
                
            }else{

                $data = array(
                    'file' => 'uploads/files/' . $new_name,
                );
                $data = $this->security->xss_clean($data);
                $this->admin_model->edit_option($data,$id,'job_applicants');
            }
            
            redirect($_SERVER['HTTP_REFERER']);
        }
    } 

    //quotes
    public function quotes($slug='')
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'quotes';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['main_content'] = $this->load->view('templates/style_1/quotes', $data, TRUE);
        $this->load->view('index', $data);
    }

    //about us
    public function about_us($slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'About us';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['teams'] = $this->common_model->get_data($data['company']->uid, 'teams');
        $data['counters']=$this->common_model->get_home_counters($data['company']->uid,4);
        $data['galleries']=$this->common_model->get_about_us_images($data['company']->uid,4);
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/about_us', $data, TRUE);
        $this->load->view('index', $data);
    }


    public function faqs($slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Faqs';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['faqs'] = $this->common_model->get_faqs($data['company']->uid);
        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['main_content'] = $this->load->view('templates/style_1/faqs', $data, TRUE);
        $this->load->view('index', $data);
    }

    //gallery
    public function gallery($slug='')
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Gallery';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['galleries'] = $this->common_model->get_by_status($data['company']->uid, 'galleries');
        $data['main_content'] = $this->load->view('templates/style_1/gallery', $data, TRUE);
        $this->load->view('index', $data);
    }


    //page
    public function page($slug, $page_slug)
    {   
        $data = array();
        $data['page'] = 'Company';
        $data['page_title'] = 'Page';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['pages'] = $this->common_model->get_single_page($page_slug);
        if (empty($data['page'])) {
            redirect(base_url());
        }
        $data['page_name'] = $data['pages']->title;
        $data['main_content'] = $this->load->view('templates/style_1/page', $data, TRUE);
        $this->load->view('index', $data);
    }


    //get time
    public function get_time($date, $business_id, $service_id)
    {
        
        $day = date('l', strtotime($date));
        $day_id = get_day_id($day);
        $value = array();
        $value['company'] = $this->admin_model->get_business_uid($business_id);
        $service = $this->admin_model->get_by_id($service_id, 'services');
        if ($service->duration_type == 'minute') {
            $interval = $service->duration;
        }else if($service->duration_type == 'hour'){
            $interval = $service->duration * 60;
        }
        
        $slot = $this->admin_model->get_timeslot_by_day($day_id, $business_id);
        $value['times'] = get_time_slots($interval, $slot->start, $slot->end);
        $value['breaks'] = get_time_by_days($day_id, $business_id);
        

        $value['service_id'] = $service_id;
        $value['day_id'] = $day_id;
        $value['date'] = $date;
        $value['interval'] = $interval;
        $data = array();
        $data['result'] = $this->load->view('include/time_loop', $value, TRUE);

        if (empty($value['times'])) {
            $data['status'] = 0;
        } else {
            $data['status'] = 1;
        }
        die(json_encode($data));
    }

    //booking page
    public function booking($slug)
    {   
        $data = array();

        if( !empty($this->input->get('embed')) && $this->input->get('embed') == 'true'){
          $is_embed = true;
        }else{
          $is_embed = false;
        }

        $data['is_embed'] = $is_embed;
        if($is_embed == true){
          $data['page'] = FALSE;
        }

        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $this->session->set_userdata('business_slug', $slug);
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        session_insert($data['company']->uid);

        $user = $this->common_model->get_by_id($data['company']->user_id, 'users');
        if ($user->status == 2) {
            redirect(base_url());
            exit();
        }
        $data['user'] = $this->common_model->get_by_id($data['company']->user_id, 'users');
        
        $my_days = $this->admin_model->get_my_days($data['company']->uid);
        foreach ($my_days as $day) {
            if ($day['day'] != 0) {
                $myday[] = $day['day'];
            }
        }

        $days = "1,2,3,4,5,6,7";         
        $days = explode(',', $days);
        $assign_days = $myday;

        $match = array();
        $nomatch = array();

        foreach($days as $v){     
            if(in_array($v, $assign_days))
                $match[]=$v;
            else
                $nomatch[]=$v;
        }
        $data['not_available'] = $nomatch;
        $data['my_days'] = $my_days;


        $data['page'] = 'Company';
        $data['page_title'] = 'Booking';
        $data['company_id'] = $data['company']->uid;
        if ($data['company']->enable_category == 1) {
            $data['categories'] = $this->common_model->get_category_services($data['company']->uid);
        }else{
            $data['services'] = $this->common_model->get_by_company($data['company']->uid, 'services');
        }

        $data['locations'] = $this->common_model->get_locations(0, $data['company']->uid);
        $data['sub_locations'] = $this->common_model->get_locations(1, $data['company']->uid);

        $data['dialing_codes'] = $this->common_model->select_asc('dialing_codes');
        $data['main_content'] = $this->load->view('templates/style_1/booking', $data, TRUE);
        $this->load->view('index', $data);
        
    }


    public function load_sub_location($location_id)
    {
        $location = $this->common_model->get_by_id($location_id, 'locations');
        $sub_locations = $this->common_model->get_sub_locations($location_id);
        $this->session->set_userdata('location_id', $location_id);
        session_store($location->business_id, $location_id, 'location_id');

        if (empty($sub_locations)) {
            echo '<option value="0">'.trans('no-data-found').'</option>';
        }else{
            foreach ($sub_locations as $location) { 
                echo '<option value="'.$location->id.'">'.$location->name.' '.$location->address.''. '</option>';
            }
        }
    }


    public function sess_sub_location($sub_location_id)
    {
        $this->session->set_userdata('sub_location_id', $sub_location_id);
        $sub_location = $this->common_model->get_by_id($sub_location_id, 'locations');
        session_store($sub_location->business_id, $sub_location_id, 'sub_location_id');
    }


    public function confirm_booking($slug, $appointment_id)
    {
        $data = array();

        if(!empty($this->input->get('embed')) && $this->input->get('embed') == 'true'){
          $is_embed = true;
        }else{
          $is_embed = false;

          if (!is_customer() && !is_guest()) {
            redirect(base_url());
          }
        }


        
        if($is_embed == true){
          $data['page'] = FALSE;
        }
       
        $data['is_embed'] = $is_embed;
        $data['page'] = 'Company';
        $data['page_title'] = 'Booking Confirm';
        $data['menu'] = FALSE;
        $data['slug'] = $slug;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['appointment'] = $this->common_model->get_appointment_md5($appointment_id);

        $data['appointment_id'] = $data['appointment']->user_id;

        $this->session->set_userdata('appointment_id', $data['appointment']->id);
        $this->session->set_userdata('company_slug', $slug);

        $data['user'] = $this->common_model->get_by_id($data['appointment']->user_id, 'users');
        $data['main_content'] = $this->load->view('templates/style_1/booking', $data, TRUE);
        $this->load->view('index', $data);
    }


    public function check_coupon($code, $appointment_id)
    {
        if (empty($code)) {
            echo json_encode(array('st' => 0, 'msg' => '<i class="fas fa-times-circle"></i> '.trans('invalid-code'))); exit();
        }
        $appointment = $this->common_model->get_by_id($appointment_id, 'appointments');
        $service = $this->common_model->get_by_id($appointment->service_id, 'services');
        $coupon = $this->common_model->get_coupon($code, $appointment->service_id, $appointment->business_id);
        $company = $this->admin_model->get_business_uid($appointment->business_id);

        if (empty($coupon)) {
            echo json_encode(array('st' => 0, 'msg' => '<i class="fas fa-times-circle"></i> '.trans('invalid-code')));
        } else {
            if (date('Y-m-d') >= $coupon->start_date && date('Y-m-d') <= $coupon->end_date) {
            

                if ($coupon->usages_limit == 0) {
                    echo json_encode(array('st' => 0, 'msg' => '<i class="fas fa-times-circle"></i> '.trans('invalid-code'))); exit();
                }

                if ($coupon->once_per_customer == 1) {
                    $check = $this->common_model->check_coupon_apply($code, $appointment->service_id, $service->business_id, $appointment->customer_id);
                    if (isset($check)) {
                        echo json_encode(array('st' => 0, 'msg' => '<i class="fas fa-times-circle"></i> '.trans('already-applied-code'))); exit();
                    }
                }

                if ($appointment->group_booking != 0) {
                    $price = ($appointment->total_person + 1) * $service->price;
                }else{
                    $price = $service->price;
                }

                
                $data = array(
                    'code' => $code,
                    'discount' => $coupon->discount,
                    'appointment_id' => $appointment->id,
                    'business_id' => $service->business_id,
                    'service_id' => $appointment->service_id,
                    'customer_id' => $appointment->customer_id,
                    'created_at' => my_date_now()
                );
                $this->admin_model->insert($data, 'coupons_apply');

                
                $coupon_data = array(
                    'usages_limit' => $coupon->usages_limit - 1,
                    'used' => $coupon->used + 1
                );
                $this->admin_model->edit_option($coupon_data, $coupon->id, 'coupons');
                echo json_encode(array('st' => 1, 'discount' => $coupon->discount, 'total_price' => $price, 'msg' => '<i class="fas fa-check-circle"></i> '.trans('coupon-applied-successfully')));

            }else{
                echo json_encode(array('st' => 0, 'msg' => '<i class="fas fa-times-circle"></i> '.trans('invalid-code')));
            }
        }exit();
        
    }

    //confirm pay info
    public function confirm_pay_info($slug, $id)
    {
        if ($_POST) {
            
            if (is_customer()) {
                $url = base_url('customer/appointments');
            }
            if (is_guest()) {
                $url = base_url('company/booking_success/'.$slug);
            }

            $data = array(
                'pay_info' => 2,
            );
            $this->admin_model->edit_option($data, $id, 'appointments');
            echo json_encode(array('st' => 1, 'url' => $url));
        }
    }


    //booking success
    public function booking_success($slug)
    {   
        $data = array();
        if(!empty($this->input->get('embed')) && $this->input->get('embed') == 'true'){
          $is_embed = true;
        }else{
          $is_embed = false;
        }
      
        $data['is_embed'] = $is_embed;
        $data['page'] = 'Company';
        $data['page_title'] = 'Appointment Confirmation';
        $data['slug'] = $slug;
        $data['menu'] = FALSE;
        $data['company'] = $this->common_model->get_by_slug($slug, 'business');
        $data['main_content'] = $this->load->view('templates/style_1/booking_msg', $data, TRUE);
        $this->load->view('index', $data);
    }


}