<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Event extends Home_Controller {

    public function __construct()
    {
        parent::__construct();
        if (!is_user()) {
            redirect(base_url());
        }
    }

    public function index()
    {
        $data = array();
        $data['page_title'] = 'Event';  
        $data['page'] = 'Event';    
        $data['event'] = FALSE;
        $data['events'] = $this->admin_model->get_event();
        $data['categories'] = $this->admin_model->get_categories($this->business->uid, 'event', 'all');

        $data['limit'] = FALSE;
        $total = get_total_value('events');
        if (ckeck_plan_limit('events', $total) == FALSE) {
            $data['limit'] = TRUE;
        }

        $data['main_content'] = $this->load->view('admin/user/event',$data,TRUE);
        $this->load->view('admin/index',$data);
    }

    public function add()
    {   
        check_status();
        
        if($_POST)
        {   
            $id = $this->input->post('id', true);
            $data=array(
                'lang_id' => 1,
                'business_id' => $this->business->uid,
                'user_id' => user()->id,
                'category_id' => $this->input->post('category_id', true),
                'title' => $this->input->post('title', true),
                'slug' => str_slug($this->input->post('slug', true)),
                'details' => $this->input->post('details', true),
                'date' => $this->input->post('date', true),
                'time' => $this->input->post('time', true),
                'price' => $this->input->post('price', true),
                'total_seat' => $this->input->post('total_seat', true),
                'organizer_name' => $this->input->post('organizer_name', true),
                'organizer_email' => $this->input->post('organizer_email', true),
                'organizer_phone' => $this->input->post('organizer_phone', true),
                'organizer_website' => $this->input->post('organizer_website', true),
                'venue_name' => $this->input->post('venue_name', true),
                'venue_phone' => $this->input->post('venue_phone', true),
                'venue_address' => $this->input->post('venue_address', true),
                'tags' => $this->input->post('tags', true),
                'meta_tags' => $this->input->post('meta_tags', true),
                'meta_desc' => $this->input->post('meta_desc', true),
                'created_at' =>date('Y-m-d'),
                'status' => $this->input->post('status', true),
            );
            $data = $this->security->xss_clean($data);


            if (!empty($id)) {
                $this->admin_model->edit_option($data, $id, 'events');
                $this->session->set_flashdata('msg', trans('updated-successfully')); 
            } else {
                $id = $this->admin_model->insert($data, 'events');
                $this->session->set_flashdata('msg', trans('inserted-successfully')); 
            }

            if($_FILES['photo']['name'] != ''){
                $up_load = $this->admin_model->upload_image('1200');
                $data_img = array(
                    'image' => $up_load['images'],
                    'thumb' => $up_load['thumb']
                );
                $data_img = $this->security->xss_clean($data_img);
                $this->admin_model->edit_option($data_img, $id, 'events');
            }
            
            redirect(base_url('admin/event'));

        }      
        
    }

    public function edit($id)
    {  
        $data = array();
        $data['page_title'] = 'Edit';  
        $data['page'] = 'Event';     
        $data['event'] = $this->admin_model->get_by_id($id, 'events');
        $data['categories'] = $this->admin_model->get_categories($this->business->uid, 'event', 'all');
        $data['main_content'] = $this->load->view('admin/user/event',$data,TRUE);
        $this->load->view('admin/index',$data);
    }

    public function event_booking()
    {  
        $data = array();
        $data['page_title'] = 'Booking';  
        $data['page'] = 'Event';     
        $data['bookings'] = $this->admin_model->get_bookings();
        $data['main_content'] = $this->load->view('admin/user/event_booking',$data,TRUE);
        $this->load->view('admin/index',$data);
    }

    public function update_status($status, $id) 
    {
        $data = array(
            'status' => $status
        );
        $data = $this->security->xss_clean($data);
        $this->admin_model->update($data, $id,'events');
        $this->session->set_flashdata('msg', trans('update-status-successfully')); 
        redirect(base_url('admin/event'));
    }

    public function delete($id)
    {
        $this->admin_model->delete($id,'events'); 
        echo json_encode(array('st' => 1));
    }

    public function booking_delete($id)
    {
        $this->admin_model->delete($id,'event_booking'); 
        echo json_encode(array('st' => 1));
    }



    public function booking_confirm($id) 
    {
        $data = array(
            'status' => 1,
            'confirm_date' => date('Y-m-d'),
        );
        $data = $this->security->xss_clean($data);
        $this->admin_model->update($data, $id,'event_booking');
        $this->session->set_flashdata('msg', trans('booking-confirm-successfully')); 
        redirect(base_url('admin/event/event_booking'));
    }


    public function booking_cancel($id) 
    {
        $data = array(
            'status' => 2,
        );
        $data = $this->security->xss_clean($data);
        $this->admin_model->update($data, $id,'event_booking');
        $this->session->set_flashdata('msg', trans('booking-cancel-successfully')); 
        redirect(base_url('admin/event/event_booking'));
    }

}
    

