<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Job extends Home_Controller {

    public function __construct()
    {
        parent::__construct();
        if (!is_user()) {
            redirect(base_url());
        }
    }

    public function index()
    {
        $data = array();
        $data['page_title'] = 'Job';  
        $data['page'] = 'Job';  
        $data['job'] = FALSE;
        $data['jobs'] = $this->admin_model->get_job();
        $data['categories'] = $this->admin_model->get_categories($this->business->uid, 'job', 'all');
        $data['main_content'] = $this->load->view('admin/user/job',$data,TRUE);
        $this->load->view('admin/index',$data);
    }

    public function add()
    {   
        check_status();
        if($_POST)
        {   
            $id = $this->input->post('id', true);
            $data=array(
                'lang_id' => 1,
                'business_id' => $this->business->uid,
                'user_id' => user()->id,
                'title' => $this->input->post('title', true),
                'slug' => str_slug($this->input->post('slug', true)),
                'category_id' => $this->input->post('category_id', true),
                'position' => $this->input->post('position', true),
                'company_name' => $this->input->post('company_name', true),
                'vacancy' => $this->input->post('vacancy'),
                'employment_status' => $this->input->post('employment_status', true),
                'salary' => $this->input->post('salary', true),
                'location' => $this->input->post('location', true),
                'deadline' => $this->input->post('deadline', true),
                'responsibility' => $this->input->post('responsibility', true),
                'contexts' => $this->input->post('contexts',true),
                'educations' => $this->input->post('educations', true),
                'experiences' => $this->input->post('experiences', true),
                'additional_requirements' => $this->input->post('additional_requirements', true),
                'benefits' => $this->input->post('benefits', true),
                'meta_tags' => $this->input->post('meta_tags', true),
                'meta_desc' => $this->input->post('meta_desc', true),
                'status' => $this->input->post('status', true),
            );
            $data = $this->security->xss_clean($data);


            if (!empty($id)) {
                $this->admin_model->edit_option($data, $id, 'jobs');
                $this->session->set_flashdata('msg', trans('updated-successfully')); 
            } else {
                $id = $this->admin_model->insert($data, 'jobs');
                $this->session->set_flashdata('msg', trans('inserted-successfully')); 
            }
            
            redirect(base_url('admin/job'));

        }      
        
    }

    public function edit($id)
    {  
        $data = array();
        $data['page_title'] = 'Edit';
        $data['page'] = 'Job'; 
        $data['job'] = $this->admin_model->get_by_id($id, 'jobs');
        $data['categories'] = $this->admin_model->get_categories($this->business->uid, 'job', 'all');
        $data['main_content'] = $this->load->view('admin/user/job',$data,TRUE);
        $this->load->view('admin/index',$data);
    }

    public function job_applicant()
    {  
        $data = array();
        $data['page_title'] = 'Applicants';
        $data['page'] = 'Job'; 
        $data['applicants'] = $this->admin_model->get_job_applicants();
        $data['main_content'] = $this->load->view('admin/user/job_applicants',$data,TRUE);
        $this->load->view('admin/index',$data);
    }
    
    public function active($id) 
    {
        $data = array(
            'status' => 1
        );
        $data = $this->security->xss_clean($data);
        $this->admin_model->update($data, $id,'jobs');
        $this->session->set_flashdata('msg', trans('activate-successfully')); 
        redirect(base_url('admin/job'));
    }

    public function deactive($id) 
    {
        $data = array(
            'status' => 0
        );
        $data = $this->security->xss_clean($data);
        $this->admin_model->update($data, $id,'jobs');
        $this->session->set_flashdata('msg', trans('deactivate-successfully')); 
        redirect(base_url('admin/job'));
    }

    public function delete($id)
    {
        $this->admin_model->delete($id,'jobs'); 
        echo json_encode(array('st' => 1));
    }

    public function applicant_delete($id)
    {
        $this->admin_model->delete($id,'job_applicants'); 
        echo json_encode(array('st' => 1));
    }


    public function accept_apply($id) 
    {
        $data = array(
            'status' => 1,
            'confirm_date' => date('Y-m-d'),
        );
        $data = $this->security->xss_clean($data);
        $this->admin_model->update($data, $id,'job_applicants');
        $this->session->set_flashdata('msg', trans('accept-apply-successfully')); 
        redirect(base_url('admin/job/job_applicant'));
    }


    public function reject_apply($id) 
    {
        $data = array(
            'status' => 2,
        );
        $data = $this->security->xss_clean($data);
        $this->admin_model->update($data, $id,'job_applicants');
        $this->session->set_flashdata('msg', trans('cancel-apply-successfully')); 
        redirect(base_url('admin/job/job_applicant'));
    }

    public function download($id){
        $this->load->helper('download');
        $applicant= $this->admin_model->get_by_id($id, 'job_applicants');
        $file_name = basename($applicant->file);
        $data = file_get_contents($applicant->file);
        $name = $file_name;

        force_download($name, $data);
        $this->session->set_flashdata('msg', trans('download-successfully'));
    }

}
    

